# Generated by Django 4.2.11 on 2024-06-02 17:59

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('loans', '0006_loan_penalty_charged_loan_penalty_charged_date_and_more'),
        ('operations', '0009_chargedpenalty'),
    ]

    operations = [
        migrations.CreateModel(
            name='PayPenalty',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('is_export', models.BooleanField(default=True, help_text='Без галочки: не отправлять данные в 1С', verbose_name='Выгружать')),
                ('comment', models.CharField(blank=True, max_length=1024, verbose_name='Комментарий')),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
                ('pay', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='operations.pay', verbose_name='Платеж')),
            ],
            options={
                'verbose_name': 'Погашенные пени',
                'verbose_name_plural': 'Погашенные пени',
            },
        ),
    ]



# Generated by Django 4.2.11 on 2024-05-28 11:38

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('loans', '0005_delete_schedule'),
        ('operations', '0005_alter_bodyissue_amount'),
    ]

    operations = [
        migrations.AlterField(
            model_name='payinterests',
            name='is_export',
            field=models.BooleanField(default=True, help_text='Без галочки: не отправлять данные в 1С', verbose_name='Выгружать'),
        ),
        migrations.CreateModel(
            name='AutoPay',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('bank_card_id', models.PositiveIntegerField()),
                ('fee', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Комиссия')),
                ('penalty', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по пени')),
                ('interests', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по процентам')),
                ('body', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по телу')),
                ('payment_id', models.CharField(help_text='Номер в CloudPayments', max_length=64, verbose_name='TransactionId')),
                ('comment', models.CharField(blank=True, max_length=1024)),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
            ],
            options={
                'verbose_name': 'Автоплатеж',
                'verbose_name_plural': 'Автоплатеж',
            },
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-19 18:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('operations', '0002_alter_bodyissue_payment_id_alter_pay_payment_id'),
    ]

    operations = [
        migrations.AddField(
            model_name='pay',
            name='fee',
            field=models.DecimalField(decimal_places=0, default=0, max_digits=7, verbose_name='Комиссия'),
            preserve_default=False,
        ),
    ]



from django.db import models


class PayInterests(models.Model):
    created = models.DateTimeField('Создана', auto_now_add=True)
    loan = models.ForeignKey('loans.Loan', models.CASCADE, verbose_name='Займ')
    amount = models.DecimalField('Сумма', max_digits=7, decimal_places=0)
    is_export = models.BooleanField('Выгружать', default=True, help_text='Без галочки: не отправлять данные в 1С')
    comment = models.CharField('Комментарий', max_length=1024, blank=True)

    def save(self, *args, **kwargs):
        pass

    def __str__(self):
        return f'{self.pk}'

    class Meta:
        managed = False
        verbose_name = 'Погашенные проценты'
        verbose_name_plural = 'Погашенные проценты'


class PayPenalty(models.Model):
    created = models.DateTimeField('Создана', auto_now_add=True)
    loan = models.ForeignKey('loans.Loan', models.CASCADE, verbose_name='Займ')
    amount = models.DecimalField('Сумма', max_digits=7, decimal_places=0)
    is_export = models.BooleanField('Выгружать', default=True, help_text='Без галочки: не отправлять данные в 1С')
    comment = models.CharField('Комментарий', max_length=1024, blank=True)

    def save(self, *args, **kwargs):
        pass

    def __str__(self):
        return f'{self.pk}'

    class Meta:
        managed = False
        verbose_name = 'Погашенные пени'
        verbose_name_plural = 'Погашенные пени'


class PayBody(models.Model):
    created = models.DateTimeField('Создана', auto_now_add=True)
    loan = models.ForeignKey('loans.Loan', models.CASCADE, verbose_name='Займ')
    amount = models.DecimalField('Сумма', max_digits=7, decimal_places=0)
    is_export = models.BooleanField('Выгружать"', default=True, help_text='Не отправлять данные в 1С')
    comment = models.CharField('Комментарий', max_length=1024, blank=True)

    def save(self, *args, **kwargs):
        pass

    def __str__(self):
        return f'{self.pk}'

    class Meta:
        managed = False
        verbose_name = 'Погашенное тело'
        verbose_name_plural = 'Погашенное тело'



# Generated by Django 4.2.11 on 2024-04-19 16:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('operations', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='bodyissue',
            name='payment_id',
            field=models.CharField(default='', help_text='Если заполнено, значит деньги отправлены', max_length=64, verbose_name='TransactionId'),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='pay',
            name='payment_id',
            field=models.CharField(default='', help_text='Номер в CloudPayments', max_length=64, verbose_name='TransactionId'),
            preserve_default=False,
        ),
    ]



# Generated by Django 4.2.11 on 2024-05-28 11:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('operations', '0006_alter_payinterests_is_export_autopay'),
    ]

    operations = [
        migrations.AddField(
            model_name='pay',
            name='is_auto',
            field=models.BooleanField(default=False, verbose_name='Автоплатеж'),
        ),
        migrations.DeleteModel(
            name='AutoPay',
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-21 07:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('operations', '0003_pay_fee'),
    ]

    operations = [
        migrations.AlterField(
            model_name='chargedinterests',
            name='amount',
            field=models.DecimalField(decimal_places=0, max_digits=7, null=True, verbose_name='Сумма'),
        ),
    ]



# Generated by Django 4.2.11 on 2024-04-18 09:57

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('loans', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Pay',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('bank_card_id', models.PositiveIntegerField()),
                ('penalty', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по пени')),
                ('interests', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по процентам')),
                ('body', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Платеж по телу')),
                ('payment_id', models.PositiveIntegerField(help_text='Номер платежа в сервисе Payments', null=True)),
                ('comment', models.CharField(blank=True, max_length=1024)),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
            ],
            options={
                'verbose_name': 'Платежи',
                'verbose_name_plural': 'Платежи',
            },
        ),
        migrations.CreateModel(
            name='PayInterests',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('is_export', models.BooleanField(default=True, help_text='Не отправлять данные в 1С', verbose_name='Выгружать"')),
                ('comment', models.CharField(blank=True, max_length=1024, verbose_name='Комментарий')),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
                ('pay', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='operations.pay', verbose_name='Платеж')),
            ],
            options={
                'verbose_name': 'Погашенные проценты',
                'verbose_name_plural': 'Погашенные проценты',
            },
        ),
        migrations.CreateModel(
            name='PayBody',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('is_export', models.BooleanField(default=True, help_text='Не отправлять данные в 1С', verbose_name='Выгружать"')),
                ('comment', models.CharField(blank=True, max_length=1024, verbose_name='Комментарий')),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
                ('pay', models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='operations.pay', verbose_name='Платеж')),
            ],
            options={
                'verbose_name': 'Погашенное тело',
                'verbose_name_plural': 'Погашенное тело',
            },
        ),
        migrations.CreateModel(
            name='ChargedInterests',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('is_export', models.BooleanField(default=True, help_text='Не отправлять данные в 1С', verbose_name='Выгружать"')),
                ('comment', models.CharField(blank=True, max_length=1024, verbose_name='Комментарий')),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
            ],
            options={
                'verbose_name': 'Начислен проценты',
                'verbose_name_plural': 'Начислен проценты',
            },
        ),
        migrations.CreateModel(
            name='BodyIssue',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created', models.DateTimeField(auto_now_add=True, verbose_name='Создана')),
                ('bank_card_id', models.PositiveIntegerField(blank=True, help_text='Карта для займа', null=True, verbose_name='Банковская карта')),
                ('amount', models.DecimalField(decimal_places=0, max_digits=7, verbose_name='Сумма')),
                ('payment_id', models.PositiveIntegerField(help_text='Если заполнено, значит деньги отправлены', null=True)),
                ('is_export', models.BooleanField(default=True, help_text='Не отправлять данные в 1С', verbose_name='Выгружать"')),
                ('comment', models.CharField(blank=True, max_length=1024)),
                ('loan', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='loans.loan', verbose_name='Займ')),
            ],
            options={
                'verbose_name': 'Выдача займа',
                'verbose_name_plural': 'Выдача займа',
            },
        ),
    ]
